==> lambdadynamodb-1.166.1-sources.jar: software/amazon/awsconstructs/services/lambdadynamodb/LambdaToDynamoDB.java <==
package software.amazon.awsconstructs.services.lambdadynamodb;

@javax.annotation.Generated(value = "jsii-pacmak/1.63.2 (build a8a8833)", date = "2022-08-10T02:30:27.519Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdadynamodb.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-dynamodb.LambdaToDynamoDB")
public class LambdaToDynamoDB extends software.amazon.awscdk.core.Construct {

    protected LambdaToDynamoDB(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToDynamoDB(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public LambdaToDynamoDB(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDBProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.dynamodb.Table getDynamoTable() {
        return software.amazon.jsii.Kernel.get(this, "dynamoTable", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.dynamodb.Table.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDB}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDB> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDBProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDBProps.Builder();
        }

        /**
         * Whether to deploy a new VPC.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param deployVpc Whether to deploy a new VPC. This parameter is required.
         */
        public Builder deployVpc(final java.lang.Boolean deployVpc) {
            this.props.deployVpc(deployVpc);
            return this;
        }

        /**
         * Optional user provided props to override the default props.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param dynamoTableProps Optional user provided props to override the default props. This parameter is required.
         */
        public Builder dynamoTableProps(final software.amazon.awscdk.services.dynamodb.TableProps dynamoTableProps) {
            this.props.dynamoTableProps(dynamoTableProps);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * Existing instance of DynamoDB table object, providing both this and `dynamoTableProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingTableObj Existing instance of DynamoDB table object, providing both this and `dynamoTableProps` will cause an error. This parameter is required.
         */
        public Builder existingTableObj(final software.amazon.awscdk.services.dynamodb.Table existingTableObj) {
            this.props.existingTableObj(existingTableObj);
            return this;
        }

        /**
         * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case). This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Optional Name for the Lambda function environment variable set to the name of the DynamoDB table.
         * <p>
         * Default: - DDB_TABLE_NAME
         * <p>
         * @return {@code this}
         * @param tableEnvironmentVariableName Optional Name for the Lambda function environment variable set to the name of the DynamoDB table. This parameter is required.
         */
        public Builder tableEnvironmentVariableName(final java.lang.String tableEnvironmentVariableName) {
            this.props.tableEnvironmentVariableName(tableEnvironmentVariableName);
            return this;
        }

        /**
         * Optional table permissions to grant to the Lambda function.
         * <p>
         * One of the following may be specified: "All", "Read", "ReadWrite", "Write".
         * <p>
         * Default: - Read/write access is given to the Lambda function if no value is specified.
         * <p>
         * @return {@code this}
         * @param tablePermissions Optional table permissions to grant to the Lambda function. This parameter is required.
         */
        public Builder tablePermissions(final java.lang.String tablePermissions) {
            this.props.tablePermissions(tablePermissions);
            return this;
        }

        /**
         * Properties to override default properties if deployVpc is true.
         * <p>
         * @return {@code this}
         * @param vpcProps Properties to override default properties if deployVpc is true. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDB}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDB build() {
            return new software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDB(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> lambdadynamodb-2.54.1-sources.jar: software/amazon/awsconstructs/services/lambdadynamodb/LambdaToDynamoDB.java <==
package software.amazon.awsconstructs.services.lambdadynamodb;

@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-04T20:59:11.256Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdadynamodb.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-dynamodb.LambdaToDynamoDB")
public class LambdaToDynamoDB extends software.constructs.Construct {

    protected LambdaToDynamoDB(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToDynamoDB(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
     * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
     * @param props <ul><li>user provided props for the construct.</li></ul> This parameter is required.
     */
    public LambdaToDynamoDB(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDBProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.dynamodb.Table getDynamoTable() {
        return software.amazon.jsii.Kernel.get(this, "dynamoTable", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.dynamodb.Table.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDB}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDB> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
         * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDBProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDBProps.Builder();
        }

        /**
         * Whether to deploy a new VPC.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param deployVpc Whether to deploy a new VPC. This parameter is required.
         */
        public Builder deployVpc(final java.lang.Boolean deployVpc) {
            this.props.deployVpc(deployVpc);
            return this;
        }

        /**
         * Optional user provided props to override the default props.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param dynamoTableProps Optional user provided props to override the default props. This parameter is required.
         */
        public Builder dynamoTableProps(final software.amazon.awscdk.services.dynamodb.TableProps dynamoTableProps) {
            this.props.dynamoTableProps(dynamoTableProps);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and <code>lambdaFunctionProps</code> will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and <code>lambdaFunctionProps</code> will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * Existing instance of DynamoDB table object, providing both this and <code>dynamoTableProps</code> will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingTableObj Existing instance of DynamoDB table object, providing both this and <code>dynamoTableProps</code> will cause an error. This parameter is required.
         */
        public Builder existingTableObj(final software.amazon.awscdk.services.dynamodb.Table existingTableObj) {
            this.props.existingTableObj(existingTableObj);
            return this;
        }

        /**
         * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case). This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Optional Name for the Lambda function environment variable set to the name of the DynamoDB table.
         * <p>
         * Default: - DDB_TABLE_NAME
         * <p>
         * @return {@code this}
         * @param tableEnvironmentVariableName Optional Name for the Lambda function environment variable set to the name of the DynamoDB table. This parameter is required.
         */
        public Builder tableEnvironmentVariableName(final java.lang.String tableEnvironmentVariableName) {
            this.props.tableEnvironmentVariableName(tableEnvironmentVariableName);
            return this;
        }

        /**
         * Optional table permissions to grant to the Lambda function.
         * <p>
         * One of the following may be specified: "All", "Read", "ReadWrite", "Write".
         * <p>
         * Default: - Read/write access is given to the Lambda function if no value is specified.
         * <p>
         * @return {@code this}
         * @param tablePermissions Optional table permissions to grant to the Lambda function. This parameter is required.
         */
        public Builder tablePermissions(final java.lang.String tablePermissions) {
            this.props.tablePermissions(tablePermissions);
            return this;
        }

        /**
         * Properties to override default properties if deployVpc is true.
         * <p>
         * @return {@code this}
         * @param vpcProps Properties to override default properties if deployVpc is true. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDB}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDB build() {
            return new software.amazon.awsconstructs.services.lambdadynamodb.LambdaToDynamoDB(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
